@@ -4,6 +4,7 @@ from typing import TypeVar, Iterable, Dict
 from i2.signatures import Sig, name_of_obj, Command as _Command
 
 
+# TODO: Consider using functools.partial (or subclass thereof) instead of Command
 class Command(_Command):
     def _caller(self):
         def exaecute_commands_in_args():
@@ -58,9 +59,12 @@ def func_name(func):
 
 class Objdict(dict):
     """A dict, whose keys can be access as if they were attributes.
+
     >>> s = Objdict()
+
     Write it as you do with attributes or dict keys,
     get it as an attribute and a dict keys.
+
     >>> s.foo = 'bar'
     >>> assert s.foo == 'bar'
     >>> assert s['foo'] == 'bar'
@@ -69,7 +73,9 @@ class Objdict(dict):
     >>> assert s['hello'] == 'world'
     >>> hasattr(s, 'hello')
     True
+
     And you can still do dict stuff with it...
+
     >>> list(s)
     ['foo', 'hello']
     >>> list(s.items())
@@ -78,12 +84,15 @@ class Objdict(dict):
     'nope'
     >>> s.clear()
     >>> assert len(s) == 0
+
     Note: You can use anything that's a valid dict key as a key
+
     >>> s['strings with space'] = 1
     >>> s[42] = 'meaning of life'
     >>> s[('tuples', 1, None)] = 'weird'
     >>> list(s)
     ['strings with space', 42, ('tuples', 1, None)]
+
     But obviously, the only ones you'll be able to access are those that are
     valid attribute names.
     """
@@ -226,6 +235,8 @@ def build_factory(element_factory, kind, idx):
     return val
 
 
+# TODO: consider changing the following command factories to return
+#  partial(factory, **factory_kwargs) instead
 def build_element_commands(
     name, inferred_type, element_factory_for_annot, missing, dflt_element_factory
 ):
@@ -272,7 +283,9 @@ def build_element_factory(
     return element_factory, factory_kwargs
 
 
-def build_element_factory_helper(element_factory_for_annot, inferred_type, missing, args):
+def build_element_factory_helper(
+    element_factory_for_annot, inferred_type, missing, args
+):
     """
     Helper to build the element factory for VP and VK arguments
     """
